<?xml version="1.0"?>
<!-- File Name: Data.xsl -->

<!-- SQL-SELECT:
SELECT Author.author_nm, Author.mail, Author.url, Data.text, Data.date;
 FROM  forum!author INNER JOIN forum!data ;
   ON  Author.author_id = Data.author_id;
 WHERE Data.object_id = ?m.gnKey
-->

<xsl:stylesheet version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:XHTML="http://www.w3.org/TR/xhtml1">

	<xsl:output method="html" version="1.0" indent="yes" encoding="Windows-1251"/>
	
	<!-- Global parameters and external documents -->
	<xsl:param name="prmObject_id" select="'1'"/>
	<xsl:param name="prmDocSubj"/> <!-- select="document('Data/Subject.xml')" -->
	<xsl:param name="prmDocAuthor"/> <!-- select="document('Data/Author.xml')" -->
	<xsl:preserve-space elements="text"/>
	
	<xsl:template match="/">
		<xsl:apply-templates/>
	</xsl:template>
	
	<xsl:template match="data">
		<!-- For $prmObject_id only -->
		<xsl:if test="object_id = $prmObject_id">
			
			<!-- Set environment for current element  -->
			<xsl:variable name="varObject_id" select="object_id"/>
			<xsl:variable name="varSubj_id" select="subj_id"/>
			<xsl:variable name="varAuthor_id" select="author_id"/>
			<xsl:variable name="varSubj_nm" select="$prmDocSubj/VFPData/subject/subj_id[.=$varSubj_id]/parent::node()/subj_nm"/>
			<xsl:variable name="varAuthor" select="$prmDocAuthor/VFPData/author/author_id[.=$varAuthor_id]/parent::node()"/>
			<xsl:variable name="varAuthor_em" select="$varAuthor/mail/text()"/>
			<xsl:variable name="varAuthor_url" select="$varAuthor/url/text()"/>
			
			<!-- Class message -->
			<xsl:element name="DIV">
				<!-- Attributes -->
				<xsl:attribute name="class">
					<xsl:text>message</xsl:text>
				</xsl:attribute>					
				<xsl:attribute name="id">
					<xsl:value-of select="$varObject_id"/>
				</xsl:attribute>					
				
				<!-- Class date_msg -->
				<xsl:element name="DIV">
					<xsl:attribute name="class">
						<xsl:text>date_msg</xsl:text>
					</xsl:attribute>					
					<xsl:value-of select="date"/>
				</xsl:element>
				
				<!-- Class subj_nm -->
				<xsl:element name="DIV">
					<xsl:attribute name="class">
						<xsl:text>subj_nm</xsl:text>
					</xsl:attribute>					
					<xsl:value-of select="$varSubj_nm"/>
				</xsl:element>
				
				<!-- Class author_nm -->
				<xsl:element name="DIV">
					<xsl:attribute name="class">
						<xsl:text>author_nm</xsl:text>
					</xsl:attribute>					
					<xsl:value-of select="$varAuthor/author_nm"/>
					<xsl:if test="string-length($varAuthor_em)>0 and $varAuthor_em != '(None)'">
						<xsl:element name="SPAN">
							<xsl:attribute name="class">
								<xsl:text>author_em</xsl:text>
							</xsl:attribute>					
							<xsl:text> </xsl:text>
							<xsl:element name="A">
								<xsl:attribute name="href">
									<xsl:value-of select="concat('mailto:', $varAuthor_em)"/>
								</xsl:attribute>					
								<xsl:value-of select="$varAuthor_em"/>
							</xsl:element>
						</xsl:element>
					</xsl:if>
				</xsl:element>
				
				<!-- Class author_url -->
				<xsl:if test="string-length($varAuthor_url)>0">
					<xsl:element name="DIV">
						<xsl:attribute name="class">
							<xsl:text>author_url</xsl:text>
						</xsl:attribute>					
						<xsl:text>Home page: </xsl:text>
						<xsl:element name="A">
							<xsl:attribute name="href">
								<xsl:value-of select="$varAuthor_url"/>
							</xsl:attribute>					
							<xsl:value-of select="$varAuthor_url"/>
						</xsl:element>
					</xsl:element>
				</xsl:if>
				
				<xsl:element name="HR"/>
				
				<!-- Class text -->
				<xsl:element name="P">
					<xsl:attribute name="class">
						<xsl:text>text</xsl:text>
					</xsl:attribute>					
					<!-- Replace &#x0A; to <BR> -->
					<xsl:apply-templates select="text" mode="replace"/>
				</xsl:element>
			
				<xsl:element name="HR"/>
			</xsl:element>
		</xsl:if>
	</xsl:template>

	<xsl:template name="replace" match="text()" mode="replace">
		<xsl:param name="prmStr" select="."/>
		<xsl:param name="prmFor" select="'&#x0A;'"/>
		<xsl:param name="prmTo">
			<xsl:element name="BR"/>
		</xsl:param>
		<xsl:choose>
			<xsl:when test="contains($prmStr, $prmFor)">
				<xsl:value-of select="substring-before($prmStr, $prmFor)"/>
				<xsl:copy-of select="$prmTo"/>
				<xsl:call-template name="replace">
					<xsl:with-param name="prmStr" 
						select="substring-after($prmStr, $prmFor)"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$prmStr"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
</xsl:stylesheet>