<!--
/////////////////////////////////////////////
// File: contents.js
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
// Author:  Michael Drozdov
// Company: ICS Soft
// Country: Russia
// Sity:    Perm 
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
// Mailto:Drozdov@ics.perm.su 
// My Page: http://vfpdmur.narod.ru/
// ICS Page: http://ics.perm.ru/ [on Russian]
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
// Revision History:
//   Ver.  Date          Comment
//   0.1   07/06/2002    Initial version started
//   0.2   07/25/2002    1) Now used global variables from tree.js (TreeFrame)
//                       that is why any XML/XSL-file only once is loaded
//                       2) if gbPreserveSpace = true, function preserveSpace()
//                       transform substring like '&#x20[&#x20...]' into ' [&nbsp;...]'
/////////////////////////////////////////////

/////////////////////////////////////////////
// Global variables & constants
// (The values of part from them is saved in tree.js
// see section "Reset all global variables from TreeFrame"
// in fillContents() function)
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
// Source files:
var gsDataXML = "Data/Data.xml";
var gsDataXSL = "Data.xsl";
var gsSubjXML = "Data/Subject.xml";
var gsAuthorXML = "Data/Author.xml";
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
// Referencese to Microsoft.xmldom objects
var goXmlDataDoc = null;
var goXslDataDoc = null;
var goXmlSubjDoc = null;
var goXmlAuthorDoc = null;
var goXslProc = null;
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
// PROGIDs:
var gsMsxmlVersion = "3.0";
// Also you can use 4.0 versions:
//var gsMsxmlVersion = "4.0";
var gsPROGIDmsxml = "Msxml2.DOMDocument."+gsMsxmlVersion;
var gsPROGIDmsxsl = "Msxml2.FreeThreadedDOMDocument."+gsMsxmlVersion;
var gsPROGIDmstemp = "Msxml2.XSLTemplate."+gsMsxmlVersion;
var gbMsxml40 = (gsPROGIDmsxml.lastIndexOf("4.0") != (-1));
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
// Other: 
var gbPreserveSpace = true; 	// true - for use "non-breaking space" mode
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
/////////////////////////////////////////////

/////////////////////////////////////////////
// Create all Microsoft.xmldom objects 
// and load all XML/XSL-files
function createXmlDoms()
{
	if (goXmlDataDoc == null || typeof(goXmlDataDoc) == "undefined")
	{
		goXmlDataDoc = new ActiveXObject(gsPROGIDmsxml);
		if (goXmlDataDoc == null)
		{
			return false;
		}
		goXmlDataDoc.async = false;
		if (!loadXML(goXmlDataDoc, gsDataXML))
		{
			goXmlDataDoc = null;
			return false;
		}
	}
	if (goXslDataDoc == null || typeof(goXslDataDoc) == "undefined")
	{
		goXslDataDoc = new ActiveXObject(gsPROGIDmsxsl);
		if (goXslDataDoc == null)
		{
			return false;
		}
		goXslDataDoc.async = false;
		if (!loadXML(goXslDataDoc, gsDataXSL))
		{
			goXslDataDoc = null;
			return false;
		}
		// Reset parameters in xsl-document
		// according to the current XML version
		if (gbMsxml40)
		{ 
			goXslDataDoc.setProperty("SelectionNamespaces", "xmlns:xsl='http://www.w3.org/1999/XSL/Transform'");
		}
	}
	if (goXmlSubjDoc == null || typeof(goXmlSubjDoc) == "undefined")
	{
		goXmlSubjDoc = new ActiveXObject(gsPROGIDmsxml);
		if (goXmlSubjDoc == null)
		{
			return false;
		}
		goXmlSubjDoc.async = false;
		if (!loadXML(goXmlSubjDoc, gsSubjXML))
		{
			goXmlSubjDoc = null;
			return false;
		}
	}
	if (goXmlAuthorDoc == null || typeof(goXmlAuthorDoc) == "undefined")
	{
		goXmlAuthorDoc = new ActiveXObject(gsPROGIDmsxml);
		if (goXmlAuthorDoc == null)
		{
			return false;
		}
		goXmlAuthorDoc.async = false;
		if (!loadXML(goXmlAuthorDoc, gsAuthorXML))
		{
			goXmlAuthorDoc = null;
			return false;
		}
	}
	if (goXslProc == null || typeof(goXslProc) == "undefined")
	{
		goXslProc = new ActiveXObject(gsPROGIDmstemp);
		if (goXslProc == null)
		{
			return false;
		}
	}
	return true;
}

//////////////////////////////////////////////////
// Show contents for selected tree-item
function fillContents()
{
	var bRetVal = false;
	var oParent = window.parent;
	if (typeof(oParent) == "undefined")
	{
		alert("fillContents: undefined 'window.parent' property");
		return bRetVal;
	}
	if (oParent.length != 2)
	{
		alert("fillContents: no frames contained in the parent window");
		return bRetVal;
	}
	// Get seletced object_id
	var oTreeFrame = oParent.frames(0);
	var oTreeDoc = oTreeFrame.document;
	var sId = oTreeDoc.all("idObject").innerText;
	// Check value of object_id
	if (typeof(sId) == "string" && sId.length != 0)
	{
		///////////////////////////////////////////////
		// Reset all global variables from TreeFrame
		gsPROGIDmsxml = oTreeFrame.gsPROGIDmsxml;
		gsPROGIDmsxsl = oTreeFrame.gsPROGIDmsxsl;
		gsPROGIDmstemp = oTreeFrame.gsPROGIDmstemp;
		gsDataXML = oTreeFrame.gsDataXML;
		gsDataXSL = oTreeFrame.gsDataXSL;
		gsSubjXML = oTreeFrame.gsSubjXML;
		gsAuthorXML = oTreeFrame.gsAuthorXML;
		goXmlDataDoc = oTreeFrame.goXmlDataDoc;
		goXslDataDoc = oTreeFrame.goXslDataDoc;
		goXmlSubjDoc = oTreeFrame.goXmlSubjDoc;
		goXmlAuthorDoc = oTreeFrame.goXmlAuthorDoc;
		goXslProc = oTreeFrame.goXslProc;
		gbMsxml40 = oTreeFrame.gbMsxml40;
		///////////////////////////////////////////////
		// Load xml&xsl files
		if (createXmlDoms()) 
		{
			///////////////////////////////////////////////
			// Save global variables into TreeFrame
			if (oTreeFrame.goXmlAuthorDoc == null)
			{
				oTreeFrame.goXmlAuthorDoc = goXmlAuthorDoc;
			}
			if (oTreeFrame.goXslDataDoc == null)
			{
				oTreeFrame.goXslDataDoc = goXslDataDoc;
			}
			///////////////////////////////////////////////
			// Use object goXslProc for transformation
			// Set XSL-document as stylesheet
			goXslProc.stylesheet = goXslDataDoc.documentElement;
			// Create Processor
			var objXSLTProc = goXslProc.createProcessor();
			if (objXSLTProc != null)
			{
				// Set XML-document
				objXSLTProc.input = goXmlDataDoc;
				///////////////////////////////////
				// Set parameters:
				// Reset prmObject_id to object_id from selected item
				objXSLTProc.addParameter("prmObject_id", sId);
				// Set XML-documents as parameters values
				objXSLTProc.addParameter("prmDocSubj", goXmlSubjDoc);
				objXSLTProc.addParameter("prmDocAuthor", goXmlAuthorDoc);
				///////////////////////////////////
				// Do transformation
				if (objXSLTProc.transform())
				{
					// Check result
					var sRetVal = objXSLTProc.output;
					if (sRetVal.length > 0)
					{
						if (gbPreserveSpace)
						{
							// "non-breaking space" mode
							sRetVal = preserveSpace(sRetVal);
						}
						// Set result
						document.body.insertAdjacentHTML("BeforeEnd", sRetVal);
						bRetVal = true;
					}
				}
			}
			else
			{
				alert("fillContents: can not createProcessor()");
			}
		}
	}
	else
	{
		alert("fillContents: undefined selected object_id");
	}
	return bRetVal;
}

//////////////////////////////////////////////////
// Encoding space
function preserveSpace(sInput)
{
	if (typeof(sInput) != "string")
		return "";
	var sOutput = "";
	var nLastSP = 0;
	var nCurSP = 0;
	while ((nCurSP = sInput.indexOf("\x20", nLastSP)) != (-1))
	{
		if (sInput.substring(nCurSP-1, nCurSP)== "\x20")
		{
			sOutput += sInput.substring(nLastSP, nCurSP)+"&nbsp;";
		}
		else
		{
			sOutput += sInput.substring(nLastSP, nCurSP)+" ";
		}
		nLastSP = ++nCurSP;
	}
	sOutput += sInput.substr(nLastSP);
	return sOutput;
}
//-->
